@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util::Config;
 
 our $DATE = '2018-03-05'; # DATE
-our $VERSION = '1.720'; # VERSION
+our $VERSION = '1.721'; # VERSION
 
 use 5.010001;
 use strict;
@@ -105,7 +105,7 @@ sub read_config {
         log_trace "[pericmd] Reading config file '%s' ...", $path;
         my $j = 0;
         $section_read_order{GLOBAL} = [$i, $j++];
-        my @file_sections;
+        my @file_sections = ("GLOBAL");
         my $hoh = $reader->read_file(
             $path,
             sub {
@@ -357,7 +357,7 @@ Perinci::CmdLine::Util::Config - Utility routines related to config files
 
 =head1 VERSION
 
-This document describes version 1.720 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Util-Config), released on 2018-03-05.
+This document describes version 1.721 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Util-Config), released on 2018-03-05.
 
 =head1 FUNCTIONS
 
